;; Generated package description from realgud-ipdb.el  -*- no-byte-compile: t -*-
(define-package "realgud-ipdb" "1.0.0.0.20230201.44938" "Realgud front-end to ipdb" '((realgud "1.5.0") (load-relative "1.3.1") (emacs "25")) :commit "d5ad95710c521da78b04560eaa754580764835d0" :authors '(("Rocky Bernstein" . "rocky@gnu.org")) :maintainer '("Rocky Bernstein" . "rocky@gnu.org") :url "https://github.com/realgud/realgud-ipdb")
